# AxoNN

[![Build Status](https://github.com/hpcgroup/axonn/actions/workflows/unit-tests.yaml/badge.svg)](https://github.com/hpcgroup/axonn/actions)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

AxoNN is a parallel framework for training deep neural networks. 

### Installation 
Prior to the installation, [PyTorch](https://pytorch.org/get-started/locally/) must already be installed.  

```bash
pip install axonn
```

### Contributing

AxoNN is an open source project. We welcome contributions via pull requests,
and questions, feature requests, or bug reports via issues.

### Citing AxoNN

If you are referencing AxoNN in a publication, please cite the
following [paper](https://pssg.cs.umd.edu/assets/papers/2022-05-axonn-ipdps.pdf):

 * Siddharth Singh, Abhinav Bhatele. AxoNN: An asynchronous, message-driven
   parallel framework for extreme-scale deep learning In Proceedings of the
   IEEE International Parallel & Distributed Processing Symposium (IPDPS '22).
   IEEE Computer Society, May 2022.

### License

AxoNN is distributed under the terms of the Apache License (Version 2.0) with
LLVM Exceptions.

All contributions must be made under the Apache License (Version 2.0) with
LLVM Exceptions.

See [LICENSE](https://github.com/pssg-int/axonn/blob/develop/LICENSE) for
details.

SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
